summaryrefslogtreecommitdiffstats
path: root/libkdegames/kchat.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kchat.h')
-rw-r--r--libkdegames/kchat.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/libkdegames/kchat.h b/libkdegames/kchat.h
index db479bc0..5eabb9d3 100644
--- a/libkdegames/kchat.h
+++ b/libkdegames/kchat.h
@@ -19,7 +19,7 @@
#ifndef __KCHAT_H__
#define __KCHAT_H__
-#include <qstring.h>
+#include <tqstring.h>
#include "kchatbase.h"
#include <kdemacros.h>
@@ -43,7 +43,7 @@ public:
* choose to send to a single player or to all players will not be added
* as you will hardly need it in 2-player games.
**/
- KChat(QWidget* parent, bool twoPlayerGame = false);
+ KChat(TQWidget* parent, bool twoPlayerGame = false);
virtual ~KChat();
@@ -52,23 +52,23 @@ public:
* @return The name that will be shown for messages from this widget.
* That is the string from @ref setFromNickname
**/
- virtual const QString& fromName() const;
+ virtual const TQString& fromName() const;
/**
* This sets the name that will be shown on all chat widgets if this
* widget sends a message. See signalSendMessage
* @param name The name of the player owning this widget
**/
- void setFromNickname(const QString& name);
+ void setFromNickname(const TQString& name);
// TODO:
// void setPlayerList(QIntDict<QString>);// use this for non-KGame use
/**
* Adds a player nickname.
* @return The unique ID of the player
**/
- int addPlayer(const QString& nick);
+ int addPlayer(const TQString& nick);
/**
* Removes all players with this nickname. Better don't use this as it
@@ -76,7 +76,7 @@ public:
* call removePlayer(id)
* @param nick The nickname of the removed players
**/
- void removePlayer(const QString& nick);
+ void removePlayer(const TQString& nick);
/**
* Removes the player with this id, as returned by @ref addPlayer
@@ -105,7 +105,7 @@ public:
/**
* @return The nickname of the player which belongs to this id
**/
- const QString& player(int id) const;
+ const TQString& player(int id) const;
/**
* @return The ID that belongs to the local player.
@@ -124,14 +124,14 @@ signals:
* setFromNickname and player
* @param msg The message itself
**/
- void signalSendMessage(int id, const QString& msg);
+ void signalSendMessage(int id, const TQString& msg);
protected:
/**
* This emits @ref signalSendMessage and, if @ref autoAddMessages is
* true, calls @ref KChatBase::addMessage
**/
- virtual void returnPressed(const QString&);
+ virtual void returnPressed(const TQString&);
/**
* The Id of the next player. Incremented after every call.
@@ -52,23 +52,23 @@ public:
// TODO:
-// void setPlayerList(QIntDict<QString>);// use this for non-KGame use
+// void setPlayerList(TQIntDict<TQString>);// use this for non-KGame use
/**
* Adds a player nickname.